aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--discord/ext/commands/core.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/discord/ext/commands/core.py b/discord/ext/commands/core.py
index a736debb..e6f9e9c1 100644
--- a/discord/ext/commands/core.py
+++ b/discord/ext/commands/core.py
@@ -174,8 +174,8 @@ class Command(_BaseCommand):
If the command is invoked while it is disabled, then
:exc:`.DisabledCommand` is raised to the :func:`.on_command_error`
event. Defaults to ``True``.
- parent: Optional[:class:`Command`]
- The parent command that this command belongs to. ``None`` if there
+ parent: Optional[:class:`Group`]
+ The parent group that this command belongs to. ``None`` if there
isn't one.
cog: Optional[:class:`Cog`]
The cog that this command belongs to. ``None`` if there isn't one.
@@ -556,7 +556,7 @@ class Command(_BaseCommand):
@property
def parents(self):
"""List[:class:`Command`]: Retrieves the parents of this command.
If the command has no parents then it returns an empty :class:`list`.
@@ -574,7 +574,7 @@ class Command(_BaseCommand):
@property
def root_parent(self):
"""Optional[:class:`Command`]: Retrieves the root parent of this command.
If the command has no parents then it returns ``None``.
@@ -556,7 +556,7 @@ class Command(_BaseCommand):
def parents(self):
- """List[:class:`Command`]: Retrieves the parents of this command.
+ """List[:class:`Group`]: Retrieves the parents of this command.
If the command has no parents then it returns an empty :class:`list`.
@@ -574,7 +574,7 @@ class Command(_BaseCommand):
def root_parent(self):
- """Optional[:class:`Command`]: Retrieves the root parent of this command.
+ """Optional[:class:`Group`]: Retrieves the root parent of this command.
If the command has no parents then it returns ``None``.